.. Installation

Installation
============

Easy!  You can get the package from either pip or conda-forge:

.. code-block:: bash

  pip install access

|

.. code-block:: bash

   conda install -c conda-forge access

|

The only dependencies are pandas and numpy.  
Geopandas will allow convenience functions for Euclidean distances, but is not required for core methods.

Note that the library is python 3 only.

You can also clone the main branch from github:

.. code-block:: bash
  
  git clone git@github.com:pysal/access.git
  cd access/
  pip install .

|
